@@ -140,11 +140,16 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
   int                       treesize;
   char                      buf[_POSIX2_LINE_MAX];
   size_t                    size = sizeof(maxslp);
+#if (OpenBSD <= 201105)
+  int                       mib_proc[6] = {CTL_KERN, KERN_PROC2, KERN_PROC_KTHREAD, 0, sizeof(struct kinfo_proc2), 0};
+  static struct kinfo_proc2 *pinfo;
+#else
   int                       mib_proc[6] = {CTL_KERN, KERN_PROC, KERN_PROC_KTHREAD, 0, sizeof(struct kinfo_proc), 0};
+  static struct kinfo_proc *pinfo;
+#endif
   static int                mib_maxslp[] = {CTL_VM, VM_MAXSLP};
   ProcessTree_T            *pt;
   kvm_t                    *kvm_handle;
-  static struct kinfo_proc *pinfo;
 
   if (sysctl(mib_maxslp, 2, &maxslp, &size, NULL, 0) < 0) {
     LogError("system statistic error -- vm.maxslp failed");
@@ -158,18 +163,28 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
 
   size *= 2; // Add reserve for new processes which were created between calls of sysctl
   pinfo = CALLOC(1, size);
+#if (OpenBSD <= 201105)
+  mib_proc[5] = (int)(size / sizeof(struct kinfo_proc2));
+#else
   mib_proc[5] = (int)(size / sizeof(struct kinfo_proc));
+#endif
   if (sysctl(mib_proc, 6, pinfo, &size, NULL, 0) == -1) {
     FREE(pinfo);
     LogError("system statistic error -- kern.proc #2 failed");
     return FALSE;
   }
 
+#if (OpenBSD <= 201105)
+  treesize = (int)(size / sizeof(struct kinfo_proc2));
+#else
   treesize = (int)(size / sizeof(struct kinfo_proc));
+#endif
 
   pt = CALLOC(sizeof(ProcessTree_T), treesize);
 
   if (! (kvm_handle = kvm_openfiles(NULL, NULL, NULL, KVM_NO_FILES, buf))) {
+    FREE(pinfo);
+    FREE(pt);
     LogError("system statistic error -- kvm_openfiles failed: %s", buf);
     return FALSE;
   }
@@ -185,15 +200,21 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
       pt[i].status_flag |= PROCESS_ZOMBIE; //FIXME: save system service flag too (kernel threads)
     pt[i].time = get_float_time();
     char **args;
+#if (OpenBSD <= 201105)
+    if ((args = kvm_getargv2(kvm_handle, &pinfo[i], 0))) {
+#else
     if ((args = kvm_getargv(kvm_handle, &pinfo[i], 0))) {
+#endif
       StringBuffer_T cmdline = StringBuffer_create(64);;
       for (int j = 0; args[j]; j++)
         StringBuffer_append(cmdline, args[j + 1] ? "%s " : "%s", args[j]);
       pt[i].cmdline = Str_dup(StringBuffer_toString(StringBuffer_trim(cmdline)));
       StringBuffer_free(&cmdline);
     }
-    if (! pt[i].cmdline || ! *pt[i].cmdline)
+    if (! pt[i].cmdline || ! *pt[i].cmdline) {
+      FREE(pt[i].cmdline);
       pt[i].cmdline = Str_dup(pinfo[i].p_comm);
+    }
   }
   FREE(pinfo);
   kvm_close(kvm_handle);
